You can subscribe to this list here.
| 2002 |
Jan
|
Feb
|
Mar
|
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
(1) |
Oct
(122) |
Nov
(152) |
Dec
(69) |
|---|---|---|---|---|---|---|---|---|---|---|---|---|
| 2003 |
Jan
(6) |
Feb
(25) |
Mar
(73) |
Apr
(82) |
May
(24) |
Jun
(25) |
Jul
(10) |
Aug
(11) |
Sep
(10) |
Oct
(54) |
Nov
(203) |
Dec
(182) |
| 2004 |
Jan
(307) |
Feb
(305) |
Mar
(430) |
Apr
(312) |
May
(187) |
Jun
(342) |
Jul
(487) |
Aug
(637) |
Sep
(336) |
Oct
(373) |
Nov
(441) |
Dec
(210) |
| 2005 |
Jan
(385) |
Feb
(480) |
Mar
(636) |
Apr
(544) |
May
(679) |
Jun
(625) |
Jul
(810) |
Aug
(838) |
Sep
(634) |
Oct
(521) |
Nov
(965) |
Dec
(543) |
| 2006 |
Jan
(494) |
Feb
(431) |
Mar
(546) |
Apr
(411) |
May
(406) |
Jun
(322) |
Jul
(256) |
Aug
(401) |
Sep
(345) |
Oct
(542) |
Nov
(308) |
Dec
(481) |
| 2007 |
Jan
(427) |
Feb
(326) |
Mar
(367) |
Apr
(255) |
May
(244) |
Jun
(204) |
Jul
(223) |
Aug
(231) |
Sep
(354) |
Oct
(374) |
Nov
(497) |
Dec
(362) |
| 2008 |
Jan
(322) |
Feb
(482) |
Mar
(658) |
Apr
(422) |
May
(476) |
Jun
(396) |
Jul
(455) |
Aug
(267) |
Sep
(280) |
Oct
(253) |
Nov
(232) |
Dec
(304) |
| 2009 |
Jan
(486) |
Feb
(470) |
Mar
(458) |
Apr
(423) |
May
(696) |
Jun
(461) |
Jul
(551) |
Aug
(575) |
Sep
(134) |
Oct
(110) |
Nov
(157) |
Dec
(102) |
| 2010 |
Jan
(226) |
Feb
(86) |
Mar
(147) |
Apr
(117) |
May
(107) |
Jun
(203) |
Jul
(193) |
Aug
(238) |
Sep
(300) |
Oct
(246) |
Nov
(23) |
Dec
(75) |
| 2011 |
Jan
(133) |
Feb
(195) |
Mar
(315) |
Apr
(200) |
May
(267) |
Jun
(293) |
Jul
(353) |
Aug
(237) |
Sep
(278) |
Oct
(611) |
Nov
(274) |
Dec
(260) |
| 2012 |
Jan
(303) |
Feb
(391) |
Mar
(417) |
Apr
(441) |
May
(488) |
Jun
(655) |
Jul
(590) |
Aug
(610) |
Sep
(526) |
Oct
(478) |
Nov
(359) |
Dec
(372) |
| 2013 |
Jan
(467) |
Feb
(226) |
Mar
(391) |
Apr
(281) |
May
(299) |
Jun
(252) |
Jul
(311) |
Aug
(352) |
Sep
(481) |
Oct
(571) |
Nov
(222) |
Dec
(231) |
| 2014 |
Jan
(185) |
Feb
(329) |
Mar
(245) |
Apr
(238) |
May
(281) |
Jun
(399) |
Jul
(382) |
Aug
(500) |
Sep
(579) |
Oct
(435) |
Nov
(487) |
Dec
(256) |
| 2015 |
Jan
(338) |
Feb
(357) |
Mar
(330) |
Apr
(294) |
May
(191) |
Jun
(108) |
Jul
(142) |
Aug
(261) |
Sep
(190) |
Oct
(54) |
Nov
(83) |
Dec
(22) |
| 2016 |
Jan
(49) |
Feb
(89) |
Mar
(33) |
Apr
(50) |
May
(27) |
Jun
(34) |
Jul
(53) |
Aug
(53) |
Sep
(98) |
Oct
(206) |
Nov
(93) |
Dec
(53) |
| 2017 |
Jan
(65) |
Feb
(82) |
Mar
(102) |
Apr
(86) |
May
(187) |
Jun
(67) |
Jul
(23) |
Aug
(93) |
Sep
(65) |
Oct
(45) |
Nov
(35) |
Dec
(17) |
| 2018 |
Jan
(26) |
Feb
(35) |
Mar
(38) |
Apr
(32) |
May
(8) |
Jun
(43) |
Jul
(27) |
Aug
(30) |
Sep
(43) |
Oct
(42) |
Nov
(38) |
Dec
(67) |
| 2019 |
Jan
(32) |
Feb
(37) |
Mar
(53) |
Apr
(64) |
May
(49) |
Jun
(18) |
Jul
(14) |
Aug
(53) |
Sep
(25) |
Oct
(30) |
Nov
(49) |
Dec
(31) |
| 2020 |
Jan
(87) |
Feb
(45) |
Mar
(37) |
Apr
(51) |
May
(99) |
Jun
(36) |
Jul
(11) |
Aug
(14) |
Sep
(20) |
Oct
(24) |
Nov
(40) |
Dec
(23) |
| 2021 |
Jan
(14) |
Feb
(53) |
Mar
(85) |
Apr
(15) |
May
(19) |
Jun
(3) |
Jul
(14) |
Aug
(1) |
Sep
(57) |
Oct
(73) |
Nov
(56) |
Dec
(22) |
| 2022 |
Jan
(3) |
Feb
(22) |
Mar
(6) |
Apr
(55) |
May
(46) |
Jun
(39) |
Jul
(15) |
Aug
(9) |
Sep
(11) |
Oct
(34) |
Nov
(20) |
Dec
(36) |
| 2023 |
Jan
(79) |
Feb
(41) |
Mar
(99) |
Apr
(169) |
May
(48) |
Jun
(16) |
Jul
(16) |
Aug
(57) |
Sep
(19) |
Oct
|
Nov
|
Dec
|
| S | M | T | W | T | F | S |
|---|---|---|---|---|---|---|
|
|
1
(3) |
2
|
3
(5) |
4
(9) |
5
(4) |
6
|
|
7
(1) |
8
(8) |
9
(8) |
10
(12) |
11
(12) |
12
(10) |
13
(4) |
|
14
(8) |
15
(9) |
16
(16) |
17
(12) |
18
(5) |
19
(5) |
20
(5) |
|
21
|
22
(13) |
23
(5) |
24
(13) |
25
(1) |
26
(3) |
27
(3) |
|
28
|
29
(1) |
30
(3) |
31
(9) |
|
|
|
Author: iraisr
Date: Fri May 5 23:13:20 2017
New Revision: 16336
Log:
Fix some spelling mistakes.
Fixes BZ#374719
Patch by: klemens <ka...@la...>
Modified:
trunk/Makefile.tool-tests.am
trunk/NEWS
trunk/README.solaris
trunk/README_MISSING_SYSCALL_OR_IOCTL
trunk/cachegrind/cg_main.c
trunk/cachegrind/cg_merge.c
trunk/callgrind/callgrind.h
trunk/callgrind/docs/cl-manual.xml
trunk/callgrind/fn.c
trunk/callgrind/global.h
trunk/callgrind/main.c
trunk/configure.ac
trunk/coregrind/launcher-darwin.c
trunk/coregrind/link_tool_exe_darwin.in
trunk/coregrind/link_tool_exe_linux.in
trunk/coregrind/link_tool_exe_solaris.in
trunk/coregrind/m_addrinfo.c
trunk/coregrind/m_aspacemgr/aspacemgr-linux.c
trunk/coregrind/m_commandline.c
trunk/coregrind/m_coredump/coredump-solaris.c
trunk/coregrind/m_debuginfo/priv_storage.h
trunk/coregrind/m_debuginfo/readdwarf.c
trunk/coregrind/m_debuginfo/readelf.c
trunk/coregrind/m_debuginfo/storage.c
trunk/coregrind/m_demangle/ansidecl.h
trunk/coregrind/m_demangle/cplus-dem.c
trunk/coregrind/m_demangle/safe-ctype.h
trunk/coregrind/m_gdbserver/README_DEVELOPERS
trunk/coregrind/m_gdbserver/m_gdbserver.c
trunk/coregrind/m_gdbserver/signals.c
trunk/coregrind/m_libcproc.c
trunk/coregrind/m_libcsignal.c
trunk/coregrind/m_mallocfree.c
trunk/coregrind/m_oset.c
trunk/coregrind/m_syswrap/syswrap-darwin.c
trunk/coregrind/m_syswrap/syswrap-solaris.c
trunk/coregrind/m_syswrap/syswrap-xen.c
trunk/coregrind/m_trampoline.S
trunk/coregrind/m_ume/elf.c
trunk/coregrind/m_wordfm.c
trunk/coregrind/pub_core_debuginfo.h
trunk/coregrind/pub_core_gdbserver.h
trunk/coregrind/pub_core_libcproc.h
trunk/coregrind/pub_core_transtab.h
trunk/coregrind/vgdb-invoker-ptrace.c
trunk/coregrind/vgdb.c
trunk/docs/internals/Darwin-notes.txt
trunk/docs/internals/arm_thumb_notes_gdbserver.txt
trunk/docs/internals/multiple-architectures.txt
trunk/docs/internals/notes.txt
trunk/docs/internals/segments-seginfos.txt
trunk/docs/internals/xml-output-protocol4.txt
trunk/docs/xml/manual-core-adv.xml
trunk/docs/xml/manual-core.xml
trunk/drd/drd_clientreq.c
trunk/drd/drd_thread.h
trunk/drd/tests/annotate_smart_pointer.cpp
trunk/exp-dhat/docs/dh-manual.xml
trunk/gdbserver_tests/filter_passsigalrm
trunk/gdbserver_tests/mcsignopass.vgtest
trunk/gdbserver_tests/nlself_invalidate.vgtest
trunk/gdbserver_tests/send_signal
trunk/gdbserver_tests/simulate_control_c
trunk/helgrind/hg_lock_n_thread.h
trunk/helgrind/hg_main.c
trunk/include/pub_tool_addrinfo.h
trunk/include/pub_tool_basics.h
trunk/include/pub_tool_stacktrace.h
trunk/include/vki/vki-linux.h
trunk/include/vki/vki-solaris-repcache.h
trunk/include/vki/vki-solaris.h
trunk/memcheck/mc_leakcheck.c
trunk/memcheck/mc_main.c
trunk/memcheck/tests/amd64/sh-mem-vec256.c
trunk/memcheck/tests/memalign2.c
trunk/memcheck/tests/new_override.vgtest
trunk/memcheck/tests/suppfreecollision.vgtest
trunk/memcheck/tests/vbit-test/vbits.c
trunk/none/tests/filter_timestamp
trunk/none/tests/libvex_test.c
trunk/none/tests/ppc32/jm-insns.c
trunk/none/tests/s390x/op_exception.c
trunk/none/tests/x86/shift_ndep.c
trunk/perf/memrw.c
trunk/perf/tinycc.c
Modified: trunk/Makefile.tool-tests.am
==============================================================================
--- trunk/Makefile.tool-tests.am (original)
+++ trunk/Makefile.tool-tests.am Fri May 5 23:13:20 2017
@@ -28,7 +28,7 @@
if VGCONF_OS_IS_SOLARIS
# Make sure that all test programs have threaded errno.
-# Disable largefile support as there are test cases explictly enabling it.
+# Disable largefile support as there are test cases explicitly enabling it.
AM_CFLAGS += -D_REENTRANT @SOLARIS_UNDEF_LARGESOURCE@
endif
Modified: trunk/NEWS
==============================================================================
--- trunk/NEWS (original)
+++ trunk/NEWS Fri May 5 23:13:20 2017
@@ -134,6 +134,7 @@
== 368864 WARNING: unhandled arm64-linux syscall: 262 (fanotify_init)
373555 Rename BBPTR to GSPTR as it denotes guest state pointer only
373938 const IRExpr arguments for matchIRExpr()
+374719 some spelling fixes
375514 valgrind_get_tls_addr() does not work in case of static TLS
375772 +1 error in get_elf_symbol_info() when computing value of 'hi' address
for ML_(find_rx_mapping)()
Modified: trunk/README.solaris
==============================================================================
--- trunk/README.solaris (original)
+++ trunk/README.solaris Fri May 5 23:13:20 2017
@@ -11,7 +11,7 @@
- A working combination of autotools is required: aclocal, autoheader,
automake and autoconf have to be found in the PATH. You should be able to
install pkg:/developer/build/automake and pkg:/developer/build/autoconf
- packages to fullfil this requirement.
+ packages to fulfil this requirement.
- System header files are required. On Solaris, these can be installed with:
# pkg install system/header
- GNU make is also required. On Solaris, this can be quickly achieved with:
Modified: trunk/README_MISSING_SYSCALL_OR_IOCTL
==============================================================================
--- trunk/README_MISSING_SYSCALL_OR_IOCTL (original)
+++ trunk/README_MISSING_SYSCALL_OR_IOCTL Fri May 5 23:13:20 2017
@@ -140,7 +140,7 @@
LINX_, LINXY, PLAX_, PLAXY.
GEN* for generic syscalls (in syswrap-generic.c), LIN* for linux
specific ones (in syswrap-linux.c) and PLA* for the platform
- dependant ones (in syswrap-$(PLATFORM)-linux.c).
+ dependent ones (in syswrap-$(PLATFORM)-linux.c).
The *XY variant if it requires a PRE() and POST() function, and
the *X_ variant if it only requires a PRE()
function.
Modified: trunk/cachegrind/cg_main.c
==============================================================================
--- trunk/cachegrind/cg_main.c (original)
+++ trunk/cachegrind/cg_main.c Fri May 5 23:13:20 2017
@@ -294,7 +294,7 @@
* As this can be detected at instrumentation time, and results
* in faster simulation, special-casing is benefical.
*
- * Abbrevations used in var/function names:
+ * Abbreviations used in var/function names:
* IrNoX - instruction read does not cross cache lines
* IrGen - generic instruction read; not detected as IrNoX
* Ir - not known / not important whether it is an IrNoX
Modified: trunk/cachegrind/cg_merge.c
==============================================================================
--- trunk/callgrind/callgrind.h (original)
+++ trunk/callgrind/callgrind.h Fri May 5 23:13:20 2017
@@ -109,7 +109,7 @@
/* Start full callgrind instrumentation if not already switched on.
When cache simulation is done, it will flush the simulated cache;
- this will lead to an artifical cache warmup phase afterwards with
+ this will lead to an artificial cache warmup phase afterwards with
cache misses which would not have happened in reality. */
#define CALLGRIND_START_INSTRUMENTATION \
VALGRIND_DO_CLIENT_REQUEST_STMT(VG_USERREQ__START_INSTRUMENTATION, \
Modified: trunk/callgrind/docs/cl-manual.xml
==============================================================================
--- trunk/callgrind/docs/cl-manual.xml (original)
+++ trunk/callgrind/docs/cl-manual.xml Fri May 5 23:13:20 2017
@@ -316,7 +316,7 @@
what is happening within a given function or starting from a given
program phase. To this end, you can disable event aggregation for
uninteresting program parts. While attribution of events to
- functions as well as producing seperate output per program phase
+ functions as well as producing separate output per program phase
can be done by other means (see previous section), there are two
benefits by disabling aggregation. First, this is very
fine-granular (e.g. just for a loop within a function). Second,
@@ -432,7 +432,7 @@
cycles, this does not hold true: callees of a function in a cycle include
the function itself. Therefore, KCachegrind does cycle detection
and skips visualization of any inclusive cost for calls inside
- of cycles. Further, all functions in a cycle are collapsed into artifical
+ of cycles. Further, all functions in a cycle are collapsed into artificial
functions called like <computeroutput>Cycle 1</computeroutput>.</para>
<para>Now, when a program exposes really big cycles (as is
@@ -1194,7 +1194,7 @@
<listitem>
<para>Start full Callgrind instrumentation if not already enabled.
When cache simulation is done, this will flush the simulated cache
- and lead to an artifical cache warmup phase afterwards with
+ and lead to an artificial cache warmup phase afterwards with
cache misses which would not have happened in reality. See also
option <option><xref linkend="opt.instr-atstart"/></option>.</para>
</listitem>
Modified: trunk/callgrind/fn.c
==============================================================================
--- trunk/callgrind/fn.c (original)
+++ trunk/callgrind/fn.c Fri May 5 23:13:20 2017
@@ -110,7 +110,7 @@
/* _ld_runtime_resolve, located in ld.so, needs special handling:
* The jump at end into the resolved function should not be
* represented as a call (as usually done in callgrind with jumps),
- * but as a return + call. Otherwise, the repeated existance of
+ * but as a return + call. Otherwise, the repeated existence of
* _ld_runtime_resolve in call chains will lead to huge cycles,
* making the profile almost worthless.
*
Modified: trunk/callgrind/global.h
==============================================================================
--- trunk/callgrind/global.h (original)
+++ trunk/callgrind/global.h Fri May 5 23:13:20 2017
@@ -347,7 +347,7 @@
* Basic Block Cost Center
*
* On demand, multiple BBCCs will be created for the same BB
- * dependend on command line options and:
+ * dependent on command line options and:
* - current function (it's possible that a BB is executed in the
* context of different functions, e.g. in manual assembler/PLT)
* - current thread ID
Modified: trunk/callgrind/main.c
==============================================================================
--- trunk/callgrind/main.c (original)
+++ trunk/callgrind/main.c Fri May 5 23:13:20 2017
@@ -1998,13 +1998,13 @@
VG_(message)(Vg_UserMsg,
"callgrind only works with --vex-iropt-unroll-thresh=0\n"
"=> resetting it back to 0\n");
- VG_(clo_vex_control).iropt_unroll_thresh = 0; // cannot be overriden.
+ VG_(clo_vex_control).iropt_unroll_thresh = 0; // cannot be overridden.
}
if (VG_(clo_vex_control).guest_chase_thresh != 0) {
VG_(message)(Vg_UserMsg,
"callgrind only works with --vex-guest-chase-thresh=0\n"
"=> resetting it back to 0\n");
- VG_(clo_vex_control).guest_chase_thresh = 0; // cannot be overriden.
+ VG_(clo_vex_control).guest_chase_thresh = 0; // cannot be overridden.
}
CLG_DEBUG(1, " dump threads: %s\n", CLG_(clo).separate_threads ? "Yes":"No");
@@ -2057,8 +2057,8 @@
= VG_(clo_px_file_backed)
= VexRegUpdSpAtMemAccess; // overridable by the user.
- VG_(clo_vex_control).iropt_unroll_thresh = 0; // cannot be overriden.
- VG_(clo_vex_control).guest_chase_thresh = 0; // cannot be overriden.
+ VG_(clo_vex_control).iropt_unroll_thresh = 0; // cannot be overridden.
+ VG_(clo_vex_control).guest_chase_thresh = 0; // cannot be overridden.
VG_(basic_tool_funcs) (CLG_(post_clo_init),
CLG_(instrument),
Modified: trunk/configure.ac
==============================================================================
--- trunk/configure.ac (original)
+++ trunk/configure.ac Fri May 5 23:13:20 2017
@@ -192,10 +192,10 @@
# Power PC returns powerpc for Big Endian. This was not changed when Little
# Endian support was added to the 64-bit architecture. The 64-bit Little
# Endian systems explicitly state le in the host_cpu. For clarity in the
-# Valgrind code, the ARCH_MAX name will state LE or BE for the endianess of
+# Valgrind code, the ARCH_MAX name will state LE or BE for the endianness of
# the 64-bit system. Big Endian is the only mode supported on 32-bit Power PC.
# The abreviation PPC or ppc refers to 32-bit and 64-bit systems with either
-# Endianess. The name PPC64 or ppc64 to 64-bit systems of either Endianess.
+# Endianness. The name PPC64 or ppc64 to 64-bit systems of either Endianness.
# The names ppc64be or PPC64BE refer to only 64-bit systems that are Big
# Endian. Similarly, ppc64le or PPC64LE refer to only 64-bit systems that are
# Little Endian.
@@ -2231,7 +2231,7 @@
CFLAGS=$safe_CFLAGS
# If the linker only supports -Ttext (not -Ttext-segment) then we will
-# have to strip any build-id ELF NOTEs from the staticly linked tools.
+# have to strip any build-id ELF NOTEs from the statically linked tools.
# Otherwise the build-id NOTE might end up at the default load address.
# (Pedantically if the linker is gold then -Ttext is fine, but newer
# gold versions also support -Ttext-segment. So just assume that unless
Modified: trunk/coregrind/launcher-darwin.c
==============================================================================
--- trunk/coregrind/launcher-darwin.c (original)
+++ trunk/coregrind/launcher-darwin.c Fri May 5 23:13:20 2017
@@ -357,7 +357,7 @@
/* Figure out the name of this executable (viz, the launcher), so
we can tell stage2. stage2 will use the name for recursive
- invokations of valgrind on child processes. */
+ invocations of valgrind on child processes. */
memset(launcher_name, 0, PATH_MAX+1);
for (i = 0; envp[i]; i++)
; /* executable path is after last envp item */
@@ -410,7 +410,7 @@
}
new_argv[new_argc++] = NULL;
- /* Build the stage2 invokation, and execve it. Bye! */
+ /* Build the stage2 invocation, and execve it. Bye! */
asprintf(&toolfile, "%s/%s-%s-darwin", valgrind_lib, toolname, arch);
if (access(toolfile, R_OK|X_OK) != 0) {
barf("tool '%s' not installed (%s) (%s)", toolname, toolfile, strerror(errno));
Modified: trunk/coregrind/link_tool_exe_darwin.in
==============================================================================
--- trunk/coregrind/link_tool_exe_darwin.in (original)
+++ trunk/coregrind/link_tool_exe_darwin.in Fri May 5 23:13:20 2017
@@ -19,7 +19,7 @@
# first arg
# the alternative load address
# all the rest of the args
-# the gcc invokation to do the final link, that
+# the gcc invocation to do the final link, that
# the build system would have done, left to itself
#
# We just let the script 'die' if something is wrong, rather than do
@@ -30,7 +30,7 @@
#
# So: what we actually do is:
#
-# Look at the specified gcc invokation. Ignore all parts of it except
+# Look at the specified gcc invocation. Ignore all parts of it except
# the *.a, *.o and -o outfile parts. Wrap them up in a new command
# which looks (eg) as follows:
#
@@ -65,7 +65,7 @@
# executable for which we are linking. We need to know this because
# we must tell the linker that, by handing it either "-arch x86_64" or
# "-arch i386". Fortunately we can figure this out by scanning the
-# gcc invokation, which itself must contain either "-arch x86_64" or
+# gcc invocation, which itself must contain either "-arch x86_64" or
# "-arch i386".
use warnings;
Modified: trunk/coregrind/link_tool_exe_linux.in
==============================================================================
--- trunk/coregrind/link_tool_exe_linux.in (original)
+++ trunk/coregrind/link_tool_exe_linux.in Fri May 5 23:13:20 2017
@@ -19,7 +19,7 @@
# first arg
# the alternative load address
# all the rest of the args
-# the gcc invokation to do the final link, that
+# the gcc invocation to do the final link, that
# the build system would have done, left to itself
#
# We just let the script 'die' if something is wrong, rather than do
Modified: trunk/coregrind/link_tool_exe_solaris.in
==============================================================================
--- trunk/coregrind/link_tool_exe_solaris.in (original)
+++ trunk/coregrind/link_tool_exe_solaris.in Fri May 5 23:13:20 2017
@@ -31,7 +31,7 @@
die "Bogus alt-load address"
if (length($ala) < 3 || index($ala, "0x") != 0);
-# the cc invokation to do the final link
+# the cc invocation to do the final link
my $cc = $ARGV[1];
# and the 'restargs' are argv[2 ..]
Modified: trunk/coregrind/m_addrinfo.c
==============================================================================
--- trunk/coregrind/m_addrinfo.c (original)
+++ trunk/coregrind/m_addrinfo.c Fri May 5 23:13:20 2017
@@ -222,7 +222,7 @@
ThreadId tid;
StackPos stackPos = StackPos_stacked;
// Default init to StackPos_stacked, to silence gcc warning.
- // We assert this value is overriden if a stack descr is produced.
+ // We assert this value is overridden if a stack descr is produced.
// First try to find a tid with stack containing a
tid = find_tid_with_stack_containing (a);
Modified: trunk/coregrind/m_aspacemgr/aspacemgr-linux.c
==============================================================================
--- trunk/coregrind/m_aspacemgr/aspacemgr-linux.c (original)
+++ trunk/coregrind/m_aspacemgr/aspacemgr-linux.c Fri May 5 23:13:20 2017
@@ -260,7 +260,7 @@
Loss of pointercheck
~~~~~~~~~~~~~~~~~~~~
Up to and including Valgrind 2.4.1, x86 segmentation was used to
- enforce seperation of V and C, so that wild writes by C could not
+ enforce separation of V and C, so that wild writes by C could not
trash V. This got called "pointercheck". Unfortunately, the new
more flexible memory layout, plus the need to be portable across
different architectures, means doing this in hardware is no longer
@@ -1861,7 +1861,7 @@
the outcome of the search and the kind of request made, decide
whether the request is allowable and what address to advise.
- The Default Policy is overriden by Policy Exception #1:
+ The Default Policy is overridden by Policy Exception #1:
If the request is for a fixed client map, we are prepared to
grant it providing all areas inside the request are either
@@ -1869,7 +1869,7 @@
other words we are prepared to let the client trash its own
mappings if it wants to.
- The Default Policy is overriden by Policy Exception #2:
+ The Default Policy is overridden by Policy Exception #2:
If the request is for a hinted client map, we are prepared to
grant it providing all areas inside the request are either
Modified: trunk/coregrind/m_commandline.c
==============================================================================
--- trunk/coregrind/m_commandline.c (original)
+++ trunk/coregrind/m_commandline.c Fri May 5 23:13:20 2017
@@ -123,7 +123,7 @@
in the stated order.
VG_(args_for_valgrind_noexecpass) is set to be the number of items
- in the first three categories. They are not passed to child invokations
+ in the first three categories. They are not passed to child invocations
at exec, whereas the last group is.
If the last group contains --command-line-only=yes, then the
Modified: trunk/coregrind/m_coredump/coredump-solaris.c
==============================================================================
--- trunk/coregrind/m_coredump/coredump-solaris.c (original)
+++ trunk/coregrind/m_coredump/coredump-solaris.c Fri May 5 23:13:20 2017
@@ -682,7 +682,7 @@
static vki_priv_impl_info_t *create_priv_info(SizeT *size)
{
- /* Size of the returned priv_impl_info_t is apriori unkown. */
+ /* Size of the returned priv_impl_info_t is apriori unknown. */
vki_priv_impl_info_t first_cut[100];
SysRes sres = VG_(do_syscall5)(SYS_privsys, VKI_PRIVSYS_GETIMPLINFO,
0, 0, (UWord) first_cut,
Modified: trunk/coregrind/m_debuginfo/priv_storage.h
==============================================================================
--- trunk/coregrind/m_debuginfo/priv_storage.h (original)
+++ trunk/coregrind/m_debuginfo/priv_storage.h Fri May 5 23:13:20 2017
@@ -913,7 +913,7 @@
cfsi_m_ix as in many case, one byte is good enough. For big
objects, 2 bytes are needed. No object has yet been found where
4 bytes are needed (but the code is ready to handle this case).
- Not covered ranges ('cfi holes') are stored explicitely in
+ Not covered ranges ('cfi holes') are stored explicitly in
cfsi_base/cfsi_m_ix as this is more memory efficient than storing
a length for each covered range : on x86 or amd64, we typically have
a hole every 8 covered ranges. On arm64, we have very few holes
Modified: trunk/coregrind/m_debuginfo/readdwarf.c
==============================================================================
--- trunk/coregrind/m_debuginfo/readdwarf.c (original)
+++ trunk/coregrind/m_debuginfo/readdwarf.c Fri May 5 23:13:20 2017
@@ -853,7 +853,7 @@
if ( acode != abcode ) {
/* This isn't illegal, but somewhat unlikely. Normally the
* first abbrev describes the first DIE, the compile_unit.
- * But maybe this abbrevation data is shared with another
+ * But maybe this abbreviation data is shared with another
* or it is a NULL entry used for padding. See para 7.5.3. */
abbrev_img = lookup_abbrev( ML_(cur_plus)(debugabbrev_img, atoffs),
acode );
@@ -1899,7 +1899,7 @@
Int data_a_f;
Addr initloc;
Int ra_reg;
- /* The rest of these fields can be modifed by
+ /* The rest of these fields can be modified by
run_CF_instruction. */
/* The LOC entry */
Addr loc;
Modified: trunk/coregrind/m_debuginfo/readelf.c
==============================================================================
--- trunk/coregrind/m_debuginfo/readelf.c (original)
+++ trunk/coregrind/m_debuginfo/readelf.c Fri May 5 23:13:20 2017
@@ -524,7 +524,7 @@
http://gcc.gnu.org/ml/gcc-patches/2004-08/msg00557.html
*/
# if defined(VGP_ppc64be_linux)
- /* Host and guest may have different Endianess, used by BE only */
+ /* Host and guest may have different Endianness, used by BE only */
is_in_opd = False;
# endif
Modified: trunk/coregrind/m_debuginfo/storage.c
==============================================================================
--- trunk/coregrind/m_debuginfo/storage.c (original)
+++ trunk/coregrind/m_debuginfo/storage.c Fri May 5 23:13:20 2017
@@ -1713,7 +1713,7 @@
di->symtab[r].sec_names = NULL;
}
/* Completely zap the entry -- paranoia to make it more
- likely we'll notice if we inadvertantly use it
+ likely we'll notice if we inadvertently use it
again. */
VG_(memset)(&di->symtab[r], 0, sizeof(DiSym));
} else {
Modified: trunk/coregrind/m_demangle/ansidecl.h
==============================================================================
--- trunk/coregrind/m_demangle/ansidecl.h (original)
+++ trunk/coregrind/m_demangle/ansidecl.h Fri May 5 23:13:20 2017
@@ -1,4 +1,4 @@
-/* ANSI and traditional C compatability macros
+/* ANSI and traditional C compatibility macros
Copyright (C) 1991-2017 Free Software Foundation, Inc.
This file is part of the GNU C Library.
Modified: trunk/coregrind/m_demangle/cplus-dem.c
==============================================================================
--- trunk/coregrind/m_demangle/cplus-dem.c (original)
+++ trunk/coregrind/m_demangle/cplus-dem.c Fri May 5 23:13:20 2017
@@ -983,7 +983,7 @@
goto unknown;
/* Most of the demangling will trivially remove chars. Operator names
- may add one char but because they are always preceeded by '__' which is
+ may add one char but because they are always preceded by '__' which is
replaced by '.', they eventually never expand the size.
A few special names such as '___elabs' add a few chars (at most 7), but
they occur only once. */
@@ -2004,7 +2004,7 @@
string_append (s, buf);
/* Numbers not otherwise delimited, might have an underscore
- appended as a delimeter, which we should skip.
+ appended as a delimiter, which we should skip.
??? This used to always remove a following underscore, which
is wrong. If other (arbitrary) cases are followed by an
Modified: trunk/coregrind/m_demangle/safe-ctype.h
==============================================================================
--- trunk/coregrind/m_demangle/safe-ctype.h (original)
+++ trunk/coregrind/m_demangle/safe-ctype.h Fri May 5 23:13:20 2017
@@ -112,7 +112,7 @@
#define TOUPPER(c) _sch_toupper[(c) & 0xff]
#define TOLOWER(c) _sch_tolower[(c) & 0xff]
-/* Prevent the users of safe-ctype.h from accidently using the routines
+/* Prevent the users of safe-ctype.h from accidentally using the routines
from ctype.h. Initially, the approach was to produce an error when
detecting that ctype.h has been included. But this was causing
trouble as ctype.h might get indirectly included as a result of
Modified: trunk/coregrind/m_gdbserver/README_DEVELOPERS
==============================================================================
--- trunk/coregrind/m_gdbserver/README_DEVELOPERS (original)
+++ trunk/coregrind/m_gdbserver/README_DEVELOPERS Fri May 5 23:13:20 2017
@@ -113,7 +113,7 @@
before modifying the value. gdb checks that the value has not changed
and so "does not believe" the information that the write watchpoint
was triggered, and continues the execution. At the next watchpoint
-occurence, gdb sees the value has changed. But the watchpoints are all
+occurrence, gdb sees the value has changed. But the watchpoints are all
reported "off by one". To avoid this, Valgrind gdbserver must
terminate the current instruction before reporting the write watchpoint.
Terminating precisely the current instruction implies to have
Modified: trunk/coregrind/m_gdbserver/m_gdbserver.c
==============================================================================
--- trunk/coregrind/m_gdbserver/m_gdbserver.c (original)
+++ trunk/coregrind/m_gdbserver/m_gdbserver.c Fri May 5 23:13:20 2017
@@ -811,7 +811,7 @@
/* When all threads are blocked in a system call, the Valgrind
scheduler cannot poll the shared memory for gdbserver activity. In
- such a case, vgdb will force the invokation of gdbserver using
+ such a case, vgdb will force the invocation of gdbserver using
ptrace. To do that, vgdb 'pushes' a call to invoke_gdbserver
on the stack using ptrace. invoke_gdbserver must not return.
Instead, it must call give_control_back_to_vgdb.
Modified: trunk/coregrind/m_gdbserver/signals.c
==============================================================================
--- trunk/coregrind/m_gdbserver/signals.c (original)
+++ trunk/coregrind/m_gdbserver/signals.c Fri May 5 23:13:20 2017
@@ -486,7 +486,7 @@
}
/* Convert a OURSIG (an enum target_signal) to the form used by the
- target operating system (refered to as the ``host'') or zero if the
+ target operating system (referred to as the ``host'') or zero if the
equivalent host signal is not available. Set/clear OURSIG_OK
accordingly. */
Modified: trunk/coregrind/m_libcproc.c
==============================================================================
--- trunk/coregrind/m_libcproc.c (original)
+++ trunk/coregrind/m_libcproc.c Fri May 5 23:13:20 2017
@@ -951,7 +951,7 @@
if (! sr_isError(res)) return 0;
- /* Make sure, argument values are determinstic upon failure */
+ /* Make sure, argument values are deterministic upon failure */
if (tv) *tv = (struct vki_timeval){ .tv_sec = 0, .tv_usec = 0 };
if (tz) *tz = (struct vki_timezone){ .tz_minuteswest = 0, .tz_dsttime = 0 };
Modified: trunk/coregrind/m_libcsignal.c
==============================================================================
--- trunk/coregrind/m_libcsignal.c (original)
+++ trunk/coregrind/m_libcsignal.c Fri May 5 23:13:20 2017
@@ -275,7 +275,7 @@
whatever we were provided with. This is OK because all the
sigaction requests come from m_signals, and are not directly
what the client program requested, so there is no chance that we
- will inadvertantly ignore the sa_tramp field requested by the
+ will inadvertently ignore the sa_tramp field requested by the
client. (In fact m_signals does ignore it when building signal
frames for the client, but that's a completely different
matter).
Modified: trunk/coregrind/m_mallocfree.c
==============================================================================
--- trunk/coregrind/m_oset.c (original)
+++ trunk/coregrind/m_oset.c Fri May 5 23:13:20 2017
@@ -31,7 +31,7 @@
//----------------------------------------------------------------------
// This file is based on:
//
-// ANSI C Library for maintainance of AVL Balanced Trees
+// ANSI C Library for maintenance of AVL Balanced Trees
// (C) 2000 Daniel Nagy, Budapest University of Technology and Economics
// Released under GNU General Public License (GPL) version 2
//----------------------------------------------------------------------
@@ -200,7 +200,7 @@
}
-// Swing to the left. Warning: no balance maintainance.
+// Swing to the left. Warning: no balance maintenance.
static void avl_swl ( AvlNode** root )
{
AvlNode* a = *root;
@@ -210,7 +210,7 @@
b->left = a;
}
-// Swing to the right. Warning: no balance maintainance.
+// Swing to the right. Warning: no balance maintenance.
static void avl_swr ( AvlNode** root )
{
AvlNode* a = *root;
@@ -220,7 +220,7 @@
b->right = a;
}
-// Balance maintainance after especially nasty swings.
+// Balance maintenance after especially nasty swings.
static void avl_nasty ( AvlNode* root )
{
switch (root->balance) {
Modified: trunk/coregrind/m_syswrap/syswrap-darwin.c
==============================================================================
--- trunk/coregrind/m_syswrap/syswrap-darwin.c (original)
+++ trunk/coregrind/m_syswrap/syswrap-darwin.c Fri May 5 23:13:20 2017
@@ -4031,7 +4031,7 @@
}
POST(getdirentries64)
{
- /* Disabled; see coments in the PRE wrapper.
+ /* Disabled; see comments in the PRE wrapper.
POST_MEM_WRITE(ARG4, sizeof(vki_off_t));
*/
// GrP fixme be specific about d_name? (fixme copied from 32 bit version)
Modified: trunk/coregrind/m_syswrap/syswrap-solaris.c
==============================================================================
--- trunk/coregrind/m_syswrap/syswrap-solaris.c (original)
+++ trunk/coregrind/m_syswrap/syswrap-solaris.c Fri May 5 23:13:20 2017
@@ -5301,7 +5301,7 @@
ARG4 = ARG3;
/* Fake the requested sigmask with a block-all mask. If the syscall
- suceeds then we will block "all" signals for a few instructions (in
+ succeeds then we will block "all" signals for a few instructions (in
syscall-x86-solaris.S) but the correct mask will be almost instantly set
again by a call to sigprocmask (also in syscall-x86-solaris.S). If the
syscall fails then the mask is not changed, so everything is ok too. */
Modified: trunk/coregrind/m_syswrap/syswrap-xen.c
==============================================================================
--- trunk/coregrind/m_syswrap/syswrap-xen.c (original)
+++ trunk/coregrind/m_syswrap/syswrap-xen.c Fri May 5 23:13:20 2017
@@ -1986,7 +1986,7 @@
case VKI_XEN_HVMOP_set_mem_type:
case VKI_XEN_HVMOP_set_mem_access:
case VKI_XEN_HVMOP_inject_trap:
- /* No output paramters */
+ /* No output parameters */
break;
case VKI_XEN_HVMOP_get_param:
Modified: trunk/coregrind/m_trampoline.S
==============================================================================
--- trunk/coregrind/m_trampoline.S (original)
+++ trunk/coregrind/m_trampoline.S Fri May 5 23:13:20 2017
@@ -1217,7 +1217,7 @@
.type VG_(s390x_linux_REDIR_FOR_index),@function
VG_(s390x_linux_REDIR_FOR_index):
#
-# %r2 = addess of string
+# %r2 = address of string
# %r3 = character to find
#
lghi %r0,255
Modified: trunk/coregrind/m_ume/elf.c
==============================================================================
--- trunk/coregrind/m_ume/elf.c (original)
+++ trunk/coregrind/m_ume/elf.c Fri May 5 23:13:20 2017
@@ -578,7 +578,7 @@
/* Later .. it appears ppc32-linux tries to put [vdso] at 1MB,
which totally screws things up, because nothing else can go
there. The size of [vdso] is around 2 or 3 pages, so bump
- the hacky load addess along by 8 * VKI_PAGE_SIZE to be safe. */
+ the hacky load address along by 8 * VKI_PAGE_SIZE to be safe. */
/* Later .. on mips64 we can't use 0x108000, because mapelf will
fail. */
# if defined(VGP_mips64_linux)
Modified: trunk/coregrind/m_wordfm.c
==============================================================================
--- trunk/coregrind/m_wordfm.c (original)
+++ trunk/coregrind/m_wordfm.c Fri May 5 23:13:20 2017
@@ -93,7 +93,7 @@
/* forward */
static Bool avl_removeroot_wrk(AvlNode** t, Word(*kCmp)(UWord,UWord));
-/* Swing to the left. Warning: no balance maintainance. */
+/* Swing to the left. Warning: no balance maintenance. */
static void avl_swl ( AvlNode** root )
{
AvlNode* a = *root;
@@ -103,7 +103,7 @@
b->child[0] = a;
}
-/* Swing to the right. Warning: no balance maintainance. */
+/* Swing to the right. Warning: no balance maintenance. */
static void avl_swr ( AvlNode** root )
{
AvlNode* a = *root;
@@ -113,7 +113,7 @@
b->child[1] = a;
}
-/* Balance maintainance after especially nasty swings. */
+/* Balance maintenance after especially nasty swings. */
static void avl_nasty ( AvlNode* root )
{
switch (root->balance) {
Modified: trunk/coregrind/pub_core_debuginfo.h
==============================================================================
--- trunk/coregrind/pub_core_debuginfo.h (original)
+++ trunk/coregrind/pub_core_debuginfo.h Fri May 5 23:13:20 2017
@@ -153,7 +153,7 @@
/* True if some FPO information is loaded.
It is useless to call VG_(use_FPO_info) if this returns False.
- Note that the return value should preferrably be cached in
+ Note that the return value should preferably be cached in
the stack unwind code, and re-queried when the debug info generation
changes. */
extern Bool VG_(FPO_info_present)(void);
Modified: trunk/coregrind/pub_core_gdbserver.h
==============================================================================
--- trunk/coregrind/pub_core_gdbserver.h (original)
+++ trunk/coregrind/pub_core_gdbserver.h Fri May 5 23:13:20 2017
@@ -230,7 +230,7 @@
} VgdbShared64;
// The below typedef makes the life of valgrind easier.
-// vgdb must however work explicitely with the specific 32 or 64 bits version.
+// vgdb must however work explicitly with the specific 32 or 64 bits version.
#if VEX_HOST_WORDSIZE == 8
typedef VgdbShared64 VgdbShared;
Modified: trunk/coregrind/pub_core_libcproc.h
==============================================================================
--- trunk/coregrind/pub_core_libcproc.h (original)
+++ trunk/coregrind/pub_core_libcproc.h Fri May 5 23:13:20 2017
@@ -39,7 +39,7 @@
#include "config.h" // Crucial: ensure we get ENABLE_INNER
#include "pub_tool_libcproc.h"
-/* The directory we look for all our auxillary files in. Useful for
+/* The directory we look for all our auxiliary files in. Useful for
running Valgrind out of a build tree without having to do "make
install". Inner valgrinds require a different lib variable, else
they end up picking up .so's etc intended for the outer
Modified: trunk/coregrind/pub_core_transtab.h
==============================================================================
--- trunk/coregrind/pub_core_transtab.h (original)
+++ trunk/coregrind/pub_core_transtab.h Fri May 5 23:13:20 2017
@@ -68,7 +68,7 @@
#define MIN_N_SECTORS 2
#define MAX_N_SECTORS 24
-/* Default for the nr of sectors, if not overriden by command line.
+/* Default for the nr of sectors, if not overridden by command line.
On Android, space is limited, so try to get by with fewer sectors.
On other platforms we can go to town. 16 sectors gives theoretical
capacity of about 440MB of JITted code in 1.05 million translations
Modified: trunk/coregrind/vgdb-invoker-ptrace.c
==============================================================================
--- trunk/coregrind/vgdb-invoker-ptrace.c (original)
+++ trunk/coregrind/vgdb-invoker-ptrace.c Fri May 5 23:13:20 2017
@@ -510,7 +510,7 @@
if (!pid_found && pid) {
/* No threads are live. Process is busy stopping.
- We need to detach from pid explicitely. */
+ We need to detach from pid explicitly. */
DEBUG(1, "no thread live => PTRACE_DETACH pid %d\n", pid);
res = ptrace (PTRACE_DETACH, pid, NULL, NULL);
if (res != 0)
Modified: trunk/coregrind/vgdb.c
==============================================================================
--- trunk/coregrind/vgdb.c (original)
+++ trunk/coregrind/vgdb.c Fri May 5 23:13:20 2017
@@ -1010,7 +1010,7 @@
write_buf(to_pid, hexcommand, strlen(hexcommand),
"writing hex command to pid", /* notify */ True);
- /* we exit of the below loop explicitely when the command has
+ /* we exit of the below loop explicitly when the command has
been handled or because a signal handler will set
shutting_down. */
while (!shutting_down) {
Modified: trunk/docs/internals/Darwin-notes.txt
==============================================================================
--- trunk/docs/internals/Darwin-notes.txt (original)
+++ trunk/docs/internals/Darwin-notes.txt Fri May 5 23:13:20 2017
@@ -39,7 +39,7 @@
using native Darwin semaphores.
Because the pipe-based semaphore intensively uses sys_read/sys_write,
-it is not surprising that it inadvertantly was eating up cancellation
+it is not surprising that it inadvertently was eating up cancellation
requests directed to client threads. With abovementioned change in
force the pipe-based semaphore appears to work correctly.
Modified: trunk/docs/internals/arm_thumb_notes_gdbserver.txt
==============================================================================
--- trunk/docs/internals/arm_thumb_notes_gdbserver.txt (original)
+++ trunk/docs/internals/arm_thumb_notes_gdbserver.txt Fri May 5 23:13:20 2017
@@ -45,8 +45,8 @@
instruction must be discarded to have the SB re-instrumented for gdbserver.
At least at this moment (r2155/r11786), the extents for ARM/thumb blocks
contains addresses with the thumb bit set. It is not clear that this is
- a good thing: extents should preferrably reference the real address range of
- instructions, not an adress range which can be "off by one" due to the
+ a good thing: extents should preferably reference the real address range of
+ instructions, not an address range which can be "off by one" due to the
fact that the instruction is a thumb instruction.
Due to this "off by one", gdbserver is discarding a range of two bytes
@@ -77,7 +77,7 @@
* use the debug info : this solution was discarded as often debug
info does not allow a 100% correct solution. debug info is acceptable
for vg.translate (which is only for internal valgrind debugging),
- but is better not used for 'end user functionnality'.
+ but is better not used for 'end user functionality'.
* Derive the thumb bit for a SB from the extent address.
This was discarded as this implies that an SB cannot mix thumb
and ARM code. This implied to disable chasing at transition between
Modified: trunk/docs/internals/multiple-architectures.txt
==============================================================================
--- trunk/docs/internals/multiple-architectures.txt (original)
+++ trunk/docs/internals/multiple-architectures.txt Fri May 5 23:13:20 2017
@@ -129,7 +129,7 @@
* the launcher, valgrind.c
* all the architecture-independent regression tests
* the performance tests
-* optionally, auxilary programs like hp2ps and valgrind-listener
+* optionally, auxiliary programs like hp2ps and valgrind-listener
In order to do that, we need to know what flags to use to build for
the primary target, and in particular whether to hand -m32 or -m64 to
@@ -148,7 +148,7 @@
This leads to the final complication: building the regression tests.
Most of them are architecture-neutral and so should be built for the
primary target. The /test/ Makefile.am's duly include
-AM_FLAG_M3264_PRI in the compilation invokations, and you should
+AM_FLAG_M3264_PRI in the compilation invocations, and you should
ensure you preserve that when adding more tests.
However, there are some arch-specific test directories (eg,
Modified: trunk/docs/internals/notes.txt
==============================================================================
--- trunk/docs/internals/notes.txt (original)
+++ trunk/docs/internals/notes.txt Fri May 5 23:13:20 2017
@@ -127,7 +127,7 @@
Redirection mechanism
~~~~~~~~~~~~~~~~~~~~~
How this works is difficult to understand. This should be fixed. The
-list of unresolved redirections should be a seperate data structure
+list of unresolved redirections should be a separate data structure
from the currently active (addr, addr) mapping.
There's a whole big #ifdef TEST section in vg_symtab2.c which has
Modified: trunk/docs/internals/segments-seginfos.txt
==============================================================================
--- trunk/docs/internals/segments-seginfos.txt (original)
+++ trunk/docs/internals/segments-seginfos.txt Fri May 5 23:13:20 2017
@@ -9,7 +9,7 @@
Segments describe memory mapped into the address space, and so any
address-space chaging operation needs to update the Segment structure.
-After the process is initalized, this means one of:
+After the process is initialized, this means one of:
* mmap
* munmap
Modified: trunk/docs/internals/xml-output-protocol4.txt
==============================================================================
--- trunk/docs/internals/xml-output-protocol4.txt (original)
+++ trunk/docs/internals/xml-output-protocol4.txt Fri May 5 23:13:20 2017
@@ -791,5 +791,5 @@
If the signal reason is not related to an address, the tag is omitted.
* STACK is defined above and shows where the thread was when it
- catched the signal. When sending the signal to itself using raise,
+ caught the signal. When sending the signal to itself using raise,
then raise is visible in this stack.
Modified: trunk/docs/xml/manual-core-adv.xml
==============================================================================
--- trunk/docs/xml/manual-core-adv.xml (original)
+++ trunk/docs/xml/manual-core-adv.xml Fri May 5 23:13:20 2017
@@ -233,7 +233,7 @@
memcheck leak search can be requested from the client program
using VALGRIND_DO_LEAK_CHECK or via the monitor command "leak_search".
Note that the syntax of the command string is only verified at
- run-time. So, if it exists, it is preferrable to use a specific
+ run-time. So, if it exists, it is preferable to use a specific
client request to have better compile time verifications of the
arguments.
</para>
@@ -1448,7 +1448,7 @@
</listitem>
<listitem>
- <para><varname>v.info exectxt</varname> shows informations about
+ <para><varname>v.info exectxt</varname> shows information about
the "executable contexts" (i.e. the stack traces) recorded by
Valgrind. For some programs, Valgrind can record a very high
number of such stack traces, causing a high memory usage. This
Modified: trunk/docs/xml/manual-core.xml
==============================================================================
--- trunk/docs/xml/manual-core.xml (original)
+++ trunk/docs/xml/manual-core.xml Fri May 5 23:13:20 2017
@@ -2115,7 +2115,7 @@
knowledge of the glibc stack cache implementation and by
examining the debug information of the pthread
library. This technique is thus somewhat fragile and might
- not work for all glibc versions. This has been succesfully
+ not work for all glibc versions. This has been successfully
tested with various glibc versions (e.g. 2.11, 2.16, 2.18)
on various platforms.</para>
</listitem>
Modified: trunk/drd/drd_clientreq.c
==============================================================================
--- trunk/drd/drd_clientreq.c (original)
+++ trunk/drd/drd_clientreq.c Fri May 5 23:13:20 2017
@@ -85,7 +85,7 @@
|| (VG_USERREQ__GDB_MONITOR_COMMAND == arg[0]
&& vg_tid == VG_INVALID_THREADID));
/* Check the consistency of vg_tid and drd_tid, unless
- vgdb has forced the invokation of a gdb monitor cmd
+ vgdb has forced the invocation of a gdb monitor cmd
when no threads was running (i.e. all threads blocked
in a syscall. In such a case, vg_tid is invalid,
its conversion to a drd thread id gives also an invalid
Modified: trunk/drd/drd_thread.h
==============================================================================
--- trunk/drd/drd_thread.h (original)
+++ trunk/drd/drd_thread.h Fri May 5 23:13:20 2017
@@ -88,9 +88,9 @@
* a corresponding OS thread that is detached.
*/
Bool detached_posix_thread;
- /** Wether recording of memory load accesses is currently enabled. */
+ /** Whether recording of memory load accesses is currently enabled. */
Bool is_recording_loads;
- /** Wether recording of memory load accesses is currently enabled. */
+ /** Whether recording of memory load accesses is currently enabled. */
Bool is_recording_stores;
/** pthread_create() nesting level. */
Int pthread_create_nesting_level;
Modified: trunk/drd/tests/annotate_smart_pointer.cpp
==============================================================================
--- trunk/drd/tests/annotate_smart_pointer.cpp (original)
+++ trunk/drd/tests/annotate_smart_pointer.cpp Fri May 5 23:13:20 2017
@@ -7,7 +7,7 @@
* - whether or not the smart pointer objects are shared over threads.
* - whether or not the smart pointer object itself is thread-safe.
*
- * Most smart pointer implemenations are not thread-safe
+ * Most smart pointer implementations are not thread-safe
* (e.g. boost::shared_ptr<>, tr1::shared_ptr<> and the smart_ptr<>
* implementation below). This means that it is not safe to modify a shared
* pointer object that is shared over threads without proper synchronization.
Modified: trunk/exp-dhat/docs/dh-manual.xml
==============================================================================
--- trunk/exp-dhat/docs/dh-manual.xml (original)
+++ trunk/exp-dhat/docs/dh-manual.xml Fri May 5 23:13:20 2017
@@ -389,7 +389,7 @@
</variablelist>
<para>One important point to note is that each allocation stack counts
-as a seperate allocation point. Because stacks by default have 12
+as a separate allocation point. Because stacks by default have 12
frames, this tends to spread data out over multiple allocation points.
You may want to use the flag --num-callers=4 or some such small
number, to reduce the spreading.</para>
Modified: trunk/gdbserver_tests/filter_passsigalrm
==============================================================================
--- trunk/gdbserver_tests/filter_passsigalrm (original)
+++ trunk/gdbserver_tests/filter_passsigalrm Fri May 5 23:13:20 2017
@@ -5,6 +5,6 @@
$dir/filter_gdb |
# Filter the number of real-time signal SIGRTMIN which
-# varies accross systems.
+# varies across systems.
sed 's/Program received signal SIG[0-9]*, Real-time event [0-9]*./Program received signal SIGxx, Real-time event xx./'
Modified: trunk/gdbserver_tests/mcsignopass.vgtest
==============================================================================
--- trunk/gdbserver_tests/mcsignopass.vgtest (original)
+++ trunk/gdbserver_tests/mcsignopass.vgtest Fri May 5 23:13:20 2017
@@ -2,7 +2,7 @@
# We detect this two ways:
# the gdb output will not contain the signal handling
# faultstatus C code will report a failure for the signal not passed
-# (i.e. SIGBUG, Test 3). Other tests will be succesful, because signals
+# (i.e. SIGBUG, Test 3). Other tests will be successful, because signals
# are eventually passed.
prereq: test -e gdb
prog: ../none/tests/faultstatus
Modified: trunk/gdbserver_tests/nlself_invalidate.vgtest
==============================================================================
--- trunk/gdbserver_tests/nlself_invalidate.vgtest (original)
+++ trunk/gdbserver_tests/nlself_invalidate.vgtest Fri May 5 23:13:20 2017
@@ -1,5 +1,5 @@
# reproduces a bug triggered by translation chaining and gdbserver
-# invalidation due to breakpoint, when there is a jump from a tranlation
+# invalidation due to breakpoint, when there is a jump from a translation
# block into itself.
prog: self_invalidate
vgopts: --tool=none --vgdb=yes --vgdb-error=0 --vgdb-prefix=./vgdb-prefix-nlself_invalidate
Modified: trunk/gdbserver_tests/send_signal
==============================================================================
--- trunk/gdbserver_tests/send_signal (original)
+++ trunk/gdbserver_tests/send_signal Fri May 5 23:13:20 2017
@@ -2,7 +2,7 @@
# send_signal sends signal $1 to the Valgrind process using prefix $2 in $3 seconds
# If there are some args after $3, the rest of these args is a command and its arg
-# which is run every second. When this command is succesful, then the sleep and
+# which is run every second. When this command is successful, then the sleep and
# the signal sending is done
SIG=$1
shift
Modified: trunk/gdbserver_tests/simulate_control_c
==============================================================================
--- trunk/gdbserver_tests/simulate_control_c (original)
+++ trunk/gdbserver_tests/simulate_control_c Fri May 5 23:13:20 2017
@@ -2,7 +2,7 @@
# simulate control_c by sending SIGUSR1 to the vgdb using prefix $1 in $2 seconds
# If there are some args after $2, the rest of these args is a command and its arg
-# which is run every second. When this command is succesful, then the sleep and
+# which is run every second. When this command is successful, then the sleep and
# the control c simul is done.
PREFIX=$1
shift
Modified: trunk/helgrind/hg_lock_n_thread.h
==============================================================================
--- trunk/helgrind/hg_lock_n_thread.h (original)
+++ trunk/helgrind/hg_lock_n_thread.h Fri May 5 23:13:20 2017
@@ -100,7 +100,7 @@
the same thing implicitly. This is necessary because for example
Solaris libc caches many objects and reuses them for different threads
and that confuses Helgrind. With libvki it would be possible to
- explictly use VG_USERREQ__HG_CLEAN_MEMORY on such objects.
+ explicitly use VG_USERREQ__HG_CLEAN_MEMORY on such objects.
Also mutex activity is ignored so that they do not impose false
ordering between creator and created thread. */
Int pthread_create_nesting_level;
Modified: trunk/helgrind/hg_main.c
==============================================================================
--- trunk/helgrind/hg_main.c (original)
+++ trunk/helgrind/hg_main.c Fri May 5 23:13:20 2017
@@ -3459,7 +3459,7 @@
The common case is that some thread T holds (eg) L1 L2 and L3 and
is repeatedly acquiring and releasing Ln, and there is no ordering
- error in what it is doing. Hence it repeatly:
+ error in what it is doing. Hence it repeatedly:
(1) searches laog to see if Ln --*--> {L1,L2,L3}, which always
produces the answer No (because there is no error).
Modified: trunk/include/pub_tool_addrinfo.h
==============================================================================
--- trunk/include/pub_tool_addrinfo.h (original)
+++ trunk/include/pub_tool_addrinfo.h Fri May 5 23:13:20 2017
@@ -145,7 +145,7 @@
// blocks and Arena blocks.
// alloc_tinfo identifies the thread that has allocated the block.
// This is used by tools such as helgrind that maintain
- // more detailed informations about client blocks.
+ // more detailed information about client blocks.
struct {
BlockKind block_kind;
const HChar* block_desc; // "block","mempool","user-defined",arena
Modified: trunk/include/pub_tool_basics.h
==============================================================================
--- trunk/include/pub_tool_basics.h (original)
+++ trunk/include/pub_tool_basics.h Fri May 5 23:13:20 2017
@@ -242,7 +242,7 @@
}
static inline Bool sr_EQ ( UInt sysno, SysRes sr1, SysRes sr2 ) {
/* This uglyness of hardcoding syscall numbers is necessary to
- avoid having this header file be dependant on
+ avoid having this header file be dependent on
include/vki/vki-scnums-mips{32,64}-linux.h. It seems pretty
safe given that it is inconceivable that the syscall numbers
for such simple syscalls would ever change. To make it
Modified: trunk/include/pub_tool_stacktrace.h
==============================================================================
--- trunk/include/pub_tool_stacktrace.h (original)
+++ trunk/include/pub_tool_stacktrace.h Fri May 5 23:13:20 2017
@@ -66,7 +66,7 @@
// Apply a function to every element in the StackTrace. The parameter
// 'n' gives the index of the passed ip. 'opaque' is an arbitrary
-// pointer provided to each invokation of 'action' (a poor man's
+// pointer provided to each invocation of 'action' (a poor man's
// closure). Doesn't go below main() unless --show-below-main=yes is
// set.
extern void VG_(apply_StackTrace)(
Modified: trunk/include/vki/vki-linux.h
==============================================================================
--- trunk/include/vki/vki-linux.h (original)
+++ trunk/include/vki/vki-linux.h Fri May 5 23:13:20 2017
@@ -527,7 +527,7 @@
* SIGBUS si_codes
*/
#define VKI_BUS_ADRALN (__VKI_SI_FAULT|1) /* invalid address alignment */
-#define VKI_BUS_ADRERR (__VKI_SI_FAULT|2) /* non-existant physical address */
+#define VKI_BUS_ADRERR (__VKI_SI_FAULT|2) /* non-existent physical address */
#define VKI_BUS_OBJERR (__VKI_SI_FAULT|3) /* object specific hardware error */
/*
@@ -2794,7 +2794,7 @@
#define VKI_SIOCSIWPOWER 0x8B2C /* set Power Management settings */
#define VKI_SIOCGIWPOWER 0x8B2D /* get Power Management settings */
-/* WPA : Generic IEEE 802.11 informatiom element (e.g., for WPA/RSN/WMM). */
+/* WPA : Generic IEEE 802.11 information element (e.g., for WPA/RSN/WMM). */
#define VKI_SIOCSIWGENIE 0x8B30 /* set generic IE */
#define VKI_SIOCGIWGENIE 0x8B31 /* get generic IE */
@@ -2821,7 +2821,7 @@
__vki_s32 value; /* The value of the parameter itself */
__vki_u8 fixed; /* Hardware should not use auto select */
__vki_u8 disabled; /* Disable the feature */
- __vki_u16 flags; /* Various specifc flags (if any) */
+ __vki_u16 flags; /* Various specific flags (if any) */
};
struct vki_iw_point
Modified: trunk/include/vki/vki-solaris-repcache.h
==============================================================================
--- trunk/include/vki/vki-solaris-repcache.h (original)
+++ trunk/include/vki/vki-solaris-repcache.h Fri May 5 23:13:20 2017
@@ -343,7 +343,7 @@
#error Unsupported repcache protocol version
#endif
-/* The following definitions are currently stable accross all repcache protocol
+/* The following definitions are current...
[truncated message content] |
|
From: <sv...@va...> - 2017-05-05 14:36:57
|
Author: petarj
Date: Fri May 5 15:36:46 2017
New Revision: 16335
Log:
mips32: remove false warnings on Android
Remove false warnings for strlen and strchr on Android.
Patch by Tamara Vlahovic.
Modified:
trunk/coregrind/m_redir.c
trunk/shared/vg_replace_strmem.c
Modified: trunk/coregrind/m_redir.c
==============================================================================
--- trunk/coregrind/m_redir.c (original)
+++ trunk/coregrind/m_redir.c Fri May 5 15:36:46 2017
@@ -1576,6 +1576,14 @@
(Addr)&VG_(mips32_linux_REDIR_FOR_index),
complain_about_stripped_glibc_ldso
);
+# if defined(VGPV_mips32_linux_android)
+ add_hardwired_spec(
+ "NONE", "__dl_strlen",
+ (Addr)&VG_(mips32_linux_REDIR_FOR_strlen),
+ NULL
+ );
+# endif
+
}
# elif defined(VGP_mips64_linux)
Modified: trunk/shared/vg_replace_strmem.c
==============================================================================
--- trunk/shared/vg_replace_strmem.c (original)
+++ trunk/shared/vg_replace_strmem.c Fri May 5 15:36:46 2017
@@ -254,6 +254,10 @@
STRCHR(VG_Z_LD_LINUX_X86_64_SO_2, index)
# endif
+#if defined(VGPV_mips32_linux_android)
+ STRCHR(NONE, __dl_strchr)
+#endif
+
#elif defined(VGO_darwin)
STRCHR(VG_Z_LIBC_SONAME, strchr)
# if DARWIN_VERS == DARWIN_10_9
|
|
From: <sv...@va...> - 2017-05-05 14:15:55
|
Author: petarj
Date: Fri May 5 15:15:48 2017
New Revision: 3361
Log:
mips: reduce compile warnings
Tune the code so it does not trigger any compile warnings.
argregs and tmpregs arrays have been enlarged to have 8 elements on mips32,
since that way we get rid of several false warnings:
warning: array index 5 is past the end of the array
(which contains 4 elements) [-Warray-bounds]
Also removing three "vassert(tmp >= 0);" as these asserts are not valid,
since tmp is an unsigned value. With the change, we get rid of:
warning: comparison of unsigned expression >= 0 is always true
[-Wtautological-compare]
Modified:
trunk/priv/host_mips_isel.c
Modified: trunk/priv/host_mips_isel.c
==============================================================================
--- trunk/priv/host_mips_isel.c (original)
+++ trunk/priv/host_mips_isel.c Fri May 5 15:15:48 2017
@@ -129,14 +129,12 @@
static HReg lookupIRTemp(ISelEnv * env, IRTemp tmp)
{
- vassert(tmp >= 0);
vassert(tmp < env->n_vregmap);
return env->vregmap[tmp];
}
static void lookupIRTemp64(HReg * vrHI, HReg * vrLO, ISelEnv * env, IRTemp tmp)
{
- vassert(tmp >= 0);
vassert(tmp < env->n_vregmap);
vassert(! hregIsInvalid(env->vregmapHI[tmp]));
*vrLO = env->vregmap[tmp];
@@ -147,7 +145,6 @@
lookupIRTempPair(HReg * vrHI, HReg * vrLO, ISelEnv * env, IRTemp tmp)
{
vassert(env->mode64);
- vassert(tmp >= 0);
vassert(tmp < env->n_vregmap);
vassert(! hregIsInvalid(env->vregmapHI[tmp]));
*vrLO = env->vregmap[tmp];
@@ -395,8 +392,8 @@
IRCallee* cee, IRType retTy, IRExpr** args )
{
MIPSCondCode cc;
- HReg argregs[MIPS_N_REGPARMS];
- HReg tmpregs[MIPS_N_REGPARMS];
+ HReg argregs[8];
+ HReg tmpregs[8];
Bool go_fast;
Int n_args, i, argreg;
UInt argiregs;
|
|
From: <sv...@va...> - 2017-05-05 13:20:24
|
Author: iraisr
Date: Fri May 5 14:20:15 2017
New Revision: 16334
Log:
Fix Valgrind internal error when dereferencing memory supplied by a client
in ptrace(getregset) and ptrace(setregset) syscall wrappers.
n-i-bz
Modified:
trunk/coregrind/m_syswrap/syswrap-linux.c
Modified: trunk/coregrind/m_syswrap/syswrap-linux.c
==============================================================================
--- trunk/coregrind/m_syswrap/syswrap-linux.c (original)
+++ trunk/coregrind/m_syswrap/syswrap-linux.c Fri May 5 14:20:15 2017
@@ -11190,12 +11190,12 @@
{
struct vki_iovec *iov = (struct vki_iovec *) arg4;
- PRE_MEM_READ("ptrace(getregset iovec->iov_base)",
- (unsigned long) &iov->iov_base, sizeof(iov->iov_base));
- PRE_MEM_READ("ptrace(getregset iovec->iov_len)",
- (unsigned long) &iov->iov_len, sizeof(iov->iov_len));
- PRE_MEM_WRITE("ptrace(getregset *(iovec->iov_base))",
- (unsigned long) iov->iov_base, iov->iov_len);
+ PRE_FIELD_READ("ptrace(getregset iovec->iov_base)", iov->iov_base);
+ PRE_FIELD_READ("ptrace(getregset iovec->iov_len)", iov->iov_len);
+ if (ML_(safe_to_deref)(iov, sizeof(struct vki_iovec))) {
+ PRE_MEM_WRITE("ptrace(getregset *(iovec->iov_base))",
+ (Addr) iov->iov_base, iov->iov_len);
+ }
}
void
@@ -11203,12 +11203,12 @@
{
struct vki_iovec *iov = (struct vki_iovec *) arg4;
- PRE_MEM_READ("ptrace(setregset iovec->iov_base)",
- (unsigned long) &iov->iov_base, sizeof(iov->iov_base));
- PRE_MEM_READ("ptrace(setregset iovec->iov_len)",
- (unsigned long) &iov->iov_len, sizeof(iov->iov_len));
- PRE_MEM_READ("ptrace(setregset *(iovec->iov_base))",
- (unsigned long) iov->iov_base, iov->iov_len);
+ PRE_FIELD_READ("ptrace(setregset iovec->iov_base)", iov->iov_base);
+ PRE_FIELD_READ("ptrace(setregset iovec->iov_len)", iov->iov_len);
+ if (ML_(safe_to_deref)(iov, sizeof(struct vki_iovec))) {
+ PRE_MEM_READ("ptrace(setregset *(iovec->iov_base))",
+ (Addr) iov->iov_base, iov->iov_len);
+ }
}
void
|
--- trunk/cachegrind/cg_merge.c (original)
+++ trunk/cachegrind/cg_merge.c Fri May 5 23:13:20 2017
@@ -12,7 +12,7 @@
nj...@va...
AVL tree code derived from
- ANSI C Library for maintainance of AVL Balanced Trees
+ ANSI C Library for maintenance of AVL Balanced Trees
(C) 2000 Daniel Nagy, Budapest University of Technology and Economics
Released under GNU General Public License (GPL) version 2
@@ -1006,7 +1006,7 @@
/* forward */
static Bool avl_removeroot_wrk(AvlNode** t, Word(*kCmp)(Word,Word));
/* Swing to the left. Warning: no balance maintainance. */
static void avl_swl ( AvlNode** root )
{
AvlNode* a = *root;
@@ -1016,7 +1016,7 @@
b->left = a;
}
/* Swing to the right. Warning: no balance maintainance. */
static void avl_swr ( AvlNode** root )
{
AvlNode* a = *root;
@@ -1026,7 +1026,7 @@
b->right = a;
}
/* Balance maintainance after especially nasty swings. */
static void avl_nasty ( AvlNode* root )
{
switch (root->balance) {
@@ -1006,7 +1006,7 @@
/* forward */
static Bool avl_removeroot_wrk(AvlNode** t, Word(*kCmp)(Word,Word));
-/* Swing to the left. Warning: no balance maintainance. */
+/* Swing to the left. Warning: no balance maintenance. */
static void avl_swl ( AvlNode** root )
{
@@ -1016,7 +1016,7 @@
b->left = a;
}
-/* Swing to the right. Warning: no balance maintainance. */
+/* Swing to the right. Warning: no balance maintenance. */
static void avl_swr ( AvlNode** root )
{
@@ -1026,7 +1026,7 @@
b->right = a;
}
-/* Balance maintainance after especially nasty swings. */
+/* Balance maintenance after especially nasty swings. */
static void avl_nasty ( AvlNode* root )
{
Modified: trunk/callgrind/callgrind.h
==============================================================================
--- trunk/coregrind/m_mallocfree.c (original)
+++ trunk/coregrind/m_mallocfree.c Fri May 5 23:13:20 2017
@@ -154,7 +154,7 @@
// 8-bytes on 32-bit machines with an 8-byte VG_MIN_MALLOC_SZB -- because
// it's too hard to make a constant expression that works perfectly in all
// cases.
// 'unsplittable' is set to NULL if superblock can be splitted, otherwise
// it is set to the address of the superblock. An unsplittable superblock
// will contain only one allocated block. An unsplittable superblock will
// be unmapped when its (only) allocated block is freed.
@@ -198,7 +198,7 @@
SizeT min_unsplittable_sblock_szB;
// Minimum unsplittable superblock size in bytes. To be marked as
// unsplittable, a superblock must have a
// size >= min_unsplittable_sblock_szB and cannot be splitted.
// So, to avoid big overhead, superblocks used to provide aligned
// blocks on big alignments are splittable.
// Unsplittable superblocks will be reclaimed when their (only)
@@ -550,7 +550,7 @@
}
// Initialise an arena. rz_szB is the (default) minimum redzone size;
-// It might be overriden by VG_(clo_redzone_size) or VG_(clo_core_redzone_size).
+// It might be overridden by VG_(clo_redzone_size) or VG_(clo_core_redzone_size).
// it might be made bigger to ensure that VG_MIN_MALLOC_SZB is observed.
static
void arena_init ( ArenaId aid, const HChar* name, SizeT rz_szB,
@@ -1859,7 +1859,7 @@
vg_assert(b_bszB >= req_bszB);
// Could we split this block and still get a useful fragment?
// A block in an unsplittable superblock can never be splitted.
frag_bszB = b_bszB - req_bszB;
if (frag_bszB >= min_useful_bszB(a)
&& (NULL == new_sb || ! new_sb->unsplittable)) {
@@ -2002,7 +2002,7 @@
/* b must be a free block, of size b_bszB.
If b is followed by another free block, merge them.
- If b is preceeded by another free block, merge them.
+ If b is preceded by another free block, merge them.
If the merge results in the superblock being fully free,
deferred_reclaimSuperblock the superblock. */
static void mergeWithFreeNeighbours (Arena* a, Superblock* sb,
@@ -2248,7 +2248,7 @@
{
/* As we will split the block given back by VG_(arena_malloc),
we have to (temporarily) disable unsplittable for this arena,
- as unsplittable superblocks cannot be splitted. */
+ as unsplittable superblocks cannot be split. */
const SizeT save_min_unsplittable_sblock_szB
= a->min_unsplittable_sblock_szB;
a->min_unsplittable_sblock_szB = MAX_PSZB;
@@ -154,7 +154,7 @@
// it's too hard to make a constant expression that works perfectly in all
// cases.
-// 'unsplittable' is set to NULL if superblock can be splitted, otherwise
+// 'unsplittable' is set to NULL if superblock can be split, otherwise
// it is set to the address of the superblock. An unsplittable superblock
// will contain only one allocated block. An unsplittable superblock will
@@ -198,7 +198,7 @@
// Minimum unsplittable superblock size in bytes. To be marked as
// unsplittable, a superblock must have a
- // size >= min_unsplittable_sblock_szB and cannot be splitted.
+ // size >= min_unsplittable_sblock_szB and cannot be split.
// So, to avoid big overhead, superblocks used to provide aligned
// blocks on big alignments are splittable.
@@ -1859,7 +1859,7 @@
vg_assert(b_bszB >= req_bszB);
// Could we split this block and still get a useful fragment?
- // A block in an unsplittable superblock can never be splitted.
+ // A block in an unsplittable superblock can never be split.
frag_bszB = b_bszB - req_bszB;
if (frag_bszB >= min_useful_bszB(a)
Modified: trunk/coregrind/m_oset.c
==============================================================================